@@ -106,23 +106,25 @@ void MSTOpt::find_opt_order()
 // October 2014 DB
 // Hack(s) for g++ on Windows 32 bit for anything higher than -O0 !!!!!
 // string manip 'safer' (???) than rnd but much slower
+// June 2016: 'rnd' fails with R3.3.1; revert to string method
 // #ifdef __x86_64
-#ifdef _WIN32
-double rnd (double x) {
-  return(roundf(x * 1e5) / 1e5);
+#ifdef __i386
+#include <sstream>
+#include <iomanip>
+double rnd(double x) {
+  std::stringstream ss;
+  ss << std::fixed << std::setprecision(5) << x;
+  return strtod(ss.str().c_str(),NULL);
 }
+//double rnd (double x) {
+//  return(roundf(x * 1e5) / 1e5);
+//}
 #else
 double rnd(double x) {
   return x;
 }
 #endif
-// #include <sstream>
-// #include <iomanip>
-// double rnd(double x) {
-//   std::stringstream ss;
-//   ss << std::fixed << std::setprecision(5) << x;
-//   return strtod(ss.str().c_str(),NULL);
-// }
+
 
 void MSTOpt::local_improvement()
 {
@@ -719,7 +721,7 @@ MSTOpt::Block_Chain MSTOpt::break_into_blocks(){
             for (int jj = bs; jj < ii; jj++) {
                 block_markers.push_back(current_order[jj]);
             }
-            Block crt_block = {true, block_markers, block_markers.size(),
+            Block crt_block = {true, block_markers, static_cast<int>(block_markers.size()),
                                block_markers[0], block_markers[block_markers.size() - 1],
                                -1, -1};
             bc.bs.push_back(crt_block);
@@ -733,7 +735,7 @@ MSTOpt::Block_Chain MSTOpt::break_into_blocks(){
         last_block_markers.push_back(current_order[jj]);
     }
     Block last_block = {true, last_block_markers,
-                        last_block_markers.size(),
+                        static_cast<int>(last_block_markers.size()),
                         last_block_markers[0], last_block_markers[last_block_markers.size() - 1],
                         -1, -1};
     bc.bs.push_back(last_block);
